@@ -14,11 +14,26 @@ def find(name):
     raise MustacheJSTemplateNotFound(name)
 
 
+def preprocess(content):
+    for preprocessor in preprocessors:
+        content = preprocessor.process(content)
 
-def _get_finders():
+    return content
+
+
+def findAll(dir, regex):
+    result = []
+    for finder in regexfinders:
+        paths = finder.findAll(dir, regex)
+        if paths is not None:
+            result += paths
+    return result
+
+
+def _get_classes(dotted_paths):
     ret = []
-    for finder_path in conf.MUSTACHEJS_FINDERS:
-        modpath, cls_name = finder_path.rsplit(".", 1)
+    for path in dotted_paths:
+        modpath, cls_name = path.rsplit(".", 1)
         try:
             mod = import_module(modpath)
         except ImportError, e:
@@ -36,10 +51,22 @@ def _get_finders():
     return ret
 
 
+def _get_finders():
+    return _get_classes(conf.MUSTACHEJS_FINDERS)
+
+
+def _get_regexfinders():
+    return _get_classes(conf.MUSTACHEJS_REGEX_FINDERS)
+
+
+def _get_preprocessors():
+    return _get_classes(conf.MUSTACHEJS_PREPROCESSORS)
+
 
 # Instantiate finders
 finders = _get_finders()
-
+regexfinders = _get_regexfinders()
+preprocessors = _get_preprocessors()
 
 
 class MustacheJSTemplateNotFound(Exception):
